package com.ningdatech.pmapi.todocenter.controller;


import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import com.ningdatech.pmapi.todocenter.bean.vo.ProcessProgressDetailVo;
import com.ningdatech.pmapi.todocenter.model.dto.req.ReqProcessHandlerDTO;
import com.ningdatech.pmapi.todocenter.model.dto.req.ToBeProcessedExportReq;
import org.springframework.web.bind.annotation.*;
import com.ningdatech.basic.model.PageVo;
import com.ningdatech.pmapi.todocenter.manage.TodoCenterManage;
import com.ningdatech.pmapi.todocenter.model.dto.req.ToBeProcessedReq;
import com.ningdatech.pmapi.todocenter.model.dto.vo.ResToBeProcessedVO;

import io.swagger.annotations.Api;
import lombok.AllArgsConstructor;

/**
 * <p>
 *  待办中心 前端控制器
 * </p>
 *
 * @author CMM
 * @since 2023-01-12
 */
@RestController
@AllArgsConstructor
@Api(tags = "待办中心控制器")
@RequestMapping("/api/v1/todo-center")
public class TodoCenterController {

    private final TodoCenterManage todoCenterManage;

    /**
     * 待办中心-待我处理项目列表查询
     * @param param
     * @return
     */
    @GetMapping("/todo-list/{isTemporaryAugment}")
    public PageVo<ResToBeProcessedVO> todoList(@ModelAttribute ToBeProcessedReq param,
                                               @PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        PageVo<ResToBeProcessedVO> result = todoCenterManage.todoProjectList(param);
        return result;
    }

    /**
     * 待办中心-待我处理项目列表导出
     * 
     * @param param
     * @param response
     * @return void
     */
    @PostMapping("/todo-list/export/{isTemporaryAugment}")
    public void exportPendingProjectList(@Valid @RequestBody ToBeProcessedExportReq param,
                                         HttpServletResponse response,@PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        todoCenterManage.exportTodoList(response,param);
    }

    /**
     * 查询流程表单数据及审批的进度步骤
     * @param instanceId 流程实例ID
     * @return 流程进度及表单详情
     */
    @GetMapping("/progress/{instanceId}/{projectId}")
    public ProcessProgressDetailVo getProcessDetail(@PathVariable String instanceId,
                                                                 @PathVariable Long projectId) {
        return todoCenterManage.getProcessDetail(instanceId, projectId);
    }

    /**
     * 审核通过，盖章并通过、退回、撤回、驳回等操作
     * @param param 操作参数
     * @return 操作结果
     */
    @PostMapping("/handler")
    public Object handler(@Valid @RequestBody ReqProcessHandlerDTO param) {
        todoCenterManage.handler(param);
        return "操作成功";
    }

    /**
     * 待办中心-我已处理项目列表查询
     * @param param
     * @return
     */
    @GetMapping("/ido-list/{isTemporaryAugment}")
    public PageVo<ResToBeProcessedVO> idoList(@ModelAttribute ToBeProcessedReq param,
                                              @PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        PageVo<ResToBeProcessedVO> result = todoCenterManage.idoList(param);
        return result;
    }
    /**
     * 待办中心-我已处理项目列表导出
     *
     * @param param
     * @param response
     * @return void
     */
    @PostMapping("/ido-list/export/{isTemporaryAugment}")
    public void exportHandledProjectList(@RequestBody ToBeProcessedExportReq param,
                                         HttpServletResponse response,@PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        todoCenterManage.idoExport(response,param);
    }

    /**
     * 待办中心-我发起的项目列表查询
     * @param param
     * @return
     */
    @GetMapping("/my-submitted-list/{isTemporaryAugment}")
    public PageVo<ResToBeProcessedVO> mySubmittedList(@ModelAttribute ToBeProcessedReq param,
                                                      @PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        PageVo<ResToBeProcessedVO> result = todoCenterManage.mySubmittedList(param);
        return result;
    }

    /**
     * 待办中心-我发起的项目列表导出
     *
     * @param param
     * @param response
     * @return void
     */
    @PostMapping("/my-submitted-list/export/{isTemporaryAugment}")
    public void exportMySubmittedList(@RequestBody ToBeProcessedExportReq param,
                                             HttpServletResponse response,@PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        todoCenterManage.exportMySubmittedList(response,param);
    }

    /**
     * 待办中心-抄送我的项目列表查询
     * @param param
     * @return
     */
    @GetMapping("/ccme-list/{isTemporaryAugment}")
    public PageVo<ResToBeProcessedVO> ccmeList(@Valid @ModelAttribute ToBeProcessedReq param,
                                               @PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        PageVo<ResToBeProcessedVO> result = todoCenterManage.ccmeList(param);
        return result;
    }

    /**
     * 待办中心-抄送我的项目列表导出
     *
     * @param param
     * @param response
     * @return void
     */
    @PostMapping("/ccme-list/export/{isTemporaryAugment}")
    public void exportCcMeProjectList(@Valid @RequestBody ToBeProcessedExportReq param, HttpServletResponse response,
                                      @PathVariable Integer isTemporaryAugment){
        param.setIsTemporaryAugment(isTemporaryAugment);
        todoCenterManage.exportCcMeProjectList(response,param);
    }
}
